==> simple-react-data-grid-2.1.2.tgz: package/src/components/dataGrid/Row.jsx <==
import React, { Component } from 'react';
import PropTypes from 'prop-types';

import RowCell from './RowCell';
import '../.././datagrid.css';
/*
* The Row component for the grid which will render - RenderRow.
* @type {class}
*/
class Row extends Component {
  constructor(props) {
    super(props);
    this.renderRows = this.renderRows.bind(this);
  }
  renderRows({ data, currentMetaData, styles }) {
    return (
      <div className="table-row" style={styles.gridTableRow}>
        {currentMetaData.headerConfig.map((columnMetaData) => {
        if (columnMetaData.customComponent) {
          const CustomComponent = columnMetaData.customComponent;
          return (
            <RowCell
              isCustomComponent
              styles={styles}
              key={columnMetaData.key}
              cellId={columnMetaData.key}
            >
              <CustomComponent rowData={data} />
            </RowCell>
          );
        } else if (columnMetaData.key === 'grid__select-column') {
          return (
            <RowCell
              styles={styles}
              key={columnMetaData.key}
              cellId={columnMetaData.key}
              title={data[columnMetaData.key]}
            >
              {data[columnMetaData.key]}
              <input
                type="checkbox"
                onChange={(e) => this.props.handleSingleCheckBoxChange(e, data)}
                name={data.id}
                checked={this.props.allRowCheckboxObject[data.id] ? 'checked' : ''}
              />
            </RowCell>
          );
        }
        return (
          <RowCell
            styles={styles}
            key={columnMetaData.key}
            cellId={columnMetaData.key}
            title={data[columnMetaData.key]}
          >
            {data[columnMetaData.key]}
          </RowCell>
        );
      })}
      </div>
    );
  }

  render() {
    const { data, currentMetaData, styles } = this.props;
    return (
      <div className="table-body-row">
        {this.renderRows({ data, currentMetaData, styles })}
      </div>
    );
  }
}

Row.propTypes = {
  allRowCheckboxObject: PropTypes.object,
  handleSingleCheckBoxChange: PropTypes.func,
  data: PropTypes.object,
  currentMetaData: PropTypes.object,
  styles: PropTypes.object,
};

Row.defaultProps = {
  allRowCheckboxObject: {},
  handleSingleCheckBoxChange: () => {},
  data: [],
  currentMetaData: {},
  styles: {},
};

export default Row;

==> simple-react-data-grid-2.2.1.tgz: package/src/components/dataGrid/Row.jsx <==
import React, { Component } from 'react';
import PropTypes from 'prop-types';

import RowCell from './RowCell';
import '../.././datagrid.css';
/**
* The Row component for the grid which will render - RenderRow.
* @type {class}
*/
class Row extends Component {
  constructor(props) {
    super(props);
    this.renderRows = this.renderRows.bind(this);
  }
  renderRows({ data, currentMetaData, styles }) {
    return (
      <div className="table-row" style={styles.gridTableRow}>
        {currentMetaData.headerConfig.map((columnMetaData) => {
        if (columnMetaData.customComponent) {
          const CustomComponent = columnMetaData.customComponent;
          return (
            <RowCell
              isCustomComponent
              styles={styles}
              key={columnMetaData.key}
              cellId={columnMetaData.key}
            >
              <CustomComponent rowData={data} />
            </RowCell>
          );
        } else if (columnMetaData.key === 'grid__select-column') {
          return (
            <RowCell
              styles={styles}
              key={columnMetaData.key}
              cellId={columnMetaData.key}
              title={data[columnMetaData.key]}
            >
              {data[columnMetaData.key]}
              <input
                type="checkbox"
                onChange={(e) => this.props.handleSingleCheckBoxChange(e, data)}
                name={data.id}
                checked={data.isChecked ? 'checked' : ''}
              />
            </RowCell>
          );
        }
        return (
          <RowCell
            styles={styles}
            key={columnMetaData.key}
            cellId={columnMetaData.key}
            title={data[columnMetaData.key]}
          >
            {data[columnMetaData.key]}
          </RowCell>
        );
      })}
      </div>
    );
  }

  render() {
    const { data, currentMetaData, styles } = this.props;
    return (
      <div className="table-body-row">
        {this.renderRows({ data, currentMetaData, styles })}
      </div>
    );
  }
}

Row.propTypes = {
  handleSingleCheckBoxChange: PropTypes.func,
  data: PropTypes.object,
  currentMetaData: PropTypes.object,
  styles: PropTypes.object,
};

Row.defaultProps = {
  handleSingleCheckBoxChange: () => {},
  data: [],
  currentMetaData: {},
  styles: {},
};

export default Row;
